@@ -196,6 +196,16 @@ class APIView(View):
             else:
                 login(self.request, user)
 
+class DevAPIView(APIView):
+    def only_accept_https(self, *args, **kwargs):
+        return False
+
+    def should_check_signature_key(self, *args, **kwargs):
+        return False
+
+    def user_authentication_method(self, *args, **kwargs):
+        return APIView.AUTH_METHODS[1]
+
 class HTMLView(View):
     def __init__(self, *args, **kwargs):
         super(HTMLView, self).__init__(*args, **kwargs)
